Properties

Struct Properties 

pub struct Properties {
    pub id: Option<u64>,
    pub addresses: Option<Vec<Address>>,
    pub online: Option<bool>,
    pub has_default_ipv4_route: Option<bool>,
    pub has_default_ipv6_route: Option<bool>,
    pub name: Option<String>,
    pub port_class: Option<PortClass>,
    pub port_identity_koid: Option<u64>,
    /* private fields */
}
Properties of a network interface.

Fields

id: Option<u64>

An opaque identifier for the interface. Its value will not be reused even if the device is removed and subsequently re-added. Immutable.

addresses: Option<Vec<Address>>

The addresses currently installed on the interface.

Addresses are sorted on [Address.addr], and no two addresses can have the same Address.addr value.

Only assigned addresses are included unless the watcher was created with [WatcherOptions.include_non_assigned_addresses] set to true.

online: Option<bool>

The device is enabled and its physical state is online.

has_default_ipv4_route: Option<bool>

Whether there is a default IPv4 route through this interface.

has_default_ipv6_route: Option<bool>

Whether there is a default IPv6 route through this interface.

name: Option<String>

The name of the interface. Immutable.

port_class: Option<PortClass>

The port class of the interface. Immutable.

port_identity_koid: Option<u64>

The KOID of the identity event vended out by the interface’s backing [fuchsia.hardware.network/Port].

Callers may use this identifier to correlate port instances to installed interfaces.

Immutable. Present for interfaces backed by a [fuchsia.hardware.network/Port], absent otherwise.